HalfEdgeMesh

Struct HalfEdgeMesh 

pub struct HalfEdgeMesh<C: Config = PolyConfig> { /* private fields */ }
Implementation of the half edge mesh. This data structure is widely used in geometry processing due to its many capabilities paired with fairly good speed and memory consumption.

This data structure allows you to represent polygon meshes where each face can have differently many vertices. (However, you can restrict this mesh to triangle meshes via the configuration.) Furthermore, it can answer all adjacency queries and exposes full edges.

The half edge mesh is a half-edge based data structure, with most of the connectivity stored per half edge. Each face and vertex just store one arbitrary half edge handle. This diagram illustrates the fields stored per half edge. (Not shown in the diagram: each half edge also stores the handle of its face.)

ee.nexte.preve.twine.target

References

Introduced in: Mäntylä, Martti. An introduction to solid modeling. Computer science press, 1988.