DenseSet

Type Alias DenseSet 

pub type DenseSet<H> = Set<H, DenseMap<H, ()>>;
A handle set that uses a bit vector to store handles.

See DenseMap for more information on memory requirements and speed.

Aliased Type

pub struct DenseSet<H> { /* private fields */ }