pub trait Config: 'static {
type NextEdge: OptionalField;
type PrevEdge: OptionalField;
}Expand description
Compile-time configuration for DirectedEdgeMesh.
To configure a directed edge mesh, either use DefaultConfig, or create
your own (preferably inhabitable) type and implement this trait.
Required Associated Types
Sourcetype NextEdge: OptionalField
type NextEdge: OptionalField
Specifies whether a next handle is stored per directed edge. This is
usually not necessary as the handle can be obtained by a simple
calculation.
TODO: check in benchmarks!
Sourcetype PrevEdge: OptionalField
type PrevEdge: OptionalField
Specifies whether a prev handle is stored per directed edge. This is
usually not necessary as the handle can be obtained by a simple
calculation.
TODO: check in benchmarks!
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".